@@ -2,7 +2,107 @@ use strict;
 use warnings;
 
 package Data::SUID;
-our $VERSION = '2.0.0'; # VERSION
+our $VERSION = '2.0.1'; # VERSION
+use threads;
+use threads::shared;
+use Crypt::Random          ( 'makerandom' );
+use Exporter               ();
+use Net::Address::Ethernet ();
+use Math::BigInt try => 'GMP';
+use Readonly;
+use namespace::clean;
+use overload '""' => 'hex';
+
+our @ISA         = ( 'Exporter' );
+our @EXPORT_OK   = ( 'suid' );
+our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
+
+sub new
+{
+    my ( $class ) = @_;
+    $class = ref( $class ) || __PACKAGE__;
+    my $time = time();
+    my $host = &_machine_ident;
+    Readonly my $id => sprintf( '%08x%s%04x%s', $time, $host, $$, &_count );
+    return bless( \$id, $class );
+}
+
+sub hex
+{
+    my ( $self ) = @_;
+    $self = &new unless ref( $self );
+    return $$self;
+}
+
+sub dec
+{
+    my ( $self ) = @_;
+    $self = &new unless ref( $self );
+    return Math::BigInt->new( '0x' . $$self );
+}
+
+sub uuencode
+{
+    my ( $self ) = @_;
+    $self = &new unless ref( $self );
+    return pack( 'u', pack( 'H*', $$self ) );
+}
+
+sub binary
+{
+    use bytes;
+    my ( $self ) = @_;
+    $self = &new unless ref( $self );
+    return pack( 'H*', $$self );
+}
+
+sub suid { __PACKAGE__->new( @_ ) }
+
+{
+    my @ident : shared;
+    my $ident : shared;
+    lock @ident;
+    lock $ident;
+    # Don't want the 24-bit OUID!
+    @ident = +( map 0 + $_, Net::Address::Ethernet::get_address() )[ 3, 4, 5 ];
+    $ident = sprintf( '%02x%02x%02x', @ident );
+
+    sub _machine_ident { wantarray ? @ident : $ident }
+}
+
+{
+    my $count_width    = 24;
+    my $count_mask     = 2**$count_width - 1;
+    my $count_format   = '%0' . int( $count_width / 4 ) . 'x';
+    my $count : shared = undef;
+
+    sub _reset_count
+    {
+        my ( $class, $value ) = @_;
+        lock $count;
+        $count = $count_mask & ( 0 + abs( $value ) )
+            if defined $value;
+        unless ( defined $count ) {
+            my $random = makerandom( Strength => 1, Uniform => 1,
+                                     Size     => $count_width );
+            # Can't share $random between threads, so coerce as string and
+            # assign to count
+            $count = "$random";
+        }
+        return $class;
+    }
+
+    sub _count
+    {
+        &_reset_count unless defined $count;
+        my $result = sprintf( $count_format, $count );
+        lock $count;
+        $count = $count_mask & ( 1 + $count );
+        return $result;
+    }
+}
+
+1;
 
 =pod
 
@@ -14,7 +114,7 @@ Data::SUID - Generates thread-safe sequential unique ids
 
 =head1 VERSION
 
-version 2.0.0
+version 2.0.1
 
 =head1 SYNOPSIS
 
@@ -47,22 +147,6 @@ primary keys within database tables. They are guaranteed to have a high
 level of uniqueness, given that they contain a timestamp, a host identifier
 and an incremented sequence number.
 
-=cut
-
-use threads;
-use threads::shared;
-use Crypt::Random          ();
-use Exporter               ();
-use Net::Address::Ethernet ();
-use Math::BigInt try => 'GMP';
-use Readonly;
-use namespace::clean;
-use overload '""' => 'hex';
-
-our @ISA         = qw(Exporter);
-our @EXPORT_OK   = qw(suid);
-our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
-
 =head1 METHODS
 
 =head2 new
@@ -71,19 +155,6 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
 
 Generates a new SUID object.
 
-=cut
-
-
-sub new
-{
-    my ($class) = @_;
-    $class = ref($class) || __PACKAGE__;
-    my $time = time();
-    my $host = &_machine_ident;
-    Readonly my $id => sprintf( '%08x%s%04x%s', $time, $host, $$, &_count );
-    return bless( \$id, $class );
-}
-
 =head2 hex
 
     $string = $suid->hex();
@@ -97,16 +168,6 @@ Returns the SUID value as a 24-character hexadecimal string.
 The SUID object's stringification operation has been overloaded to give this
 value, too.
 
-=cut
-
-
-sub hex
-{
-    my ($self) = @_;
-    $self = &new unless ref($self);
-    return $$self;
-}
-
 =head2 dec
 
     $string = $suid->dec();
@@ -115,16 +176,6 @@ sub hex
 
 Returns the SUID value as a big integer.
 
-=cut
-
-
-sub dec
-{
-    my ($self) = @_;
-    $self = &new unless ref($self);
-    return Math::BigInt->new( '0x' . $$self );
-}
-
 =head2 uuencode
 
     $string = $suid->uuencode();
@@ -133,16 +184,6 @@ sub dec
 
 Returns the SUID value as a UUENCODED string.
 
-=cut
-
-
-sub uuencode
-{
-    my ($self) = @_;
-    $self = &new unless ref($self);
-    return pack( 'u', pack( 'H*', $$self ) );
-}
-
 =head2 binary
 
     $binstr = $suid->binary();
@@ -151,17 +192,6 @@ sub uuencode
 
 Returns the SUID value as 12 bytes of binary data.
 
-=cut
-
-
-sub binary
-{
-    use bytes;
-    my ($self) = @_;
-    $self = &new unless ref($self);
-    return pack( 'H*', $$self );
-}
-
 =head1 EXPORTED FUNCTIONS
 
 =head2 suid
@@ -170,74 +200,6 @@ sub binary
 
 Generates a new SUID object.
 
-=cut
-
-
-sub suid
-{
-    return __PACKAGE__->new(@_);
-}
-
-{
-    my @ident : shared;
-    my $ident : shared;
-
-    lock @ident;
-    lock $ident;
-
-    # Don't want the 24-bit OUID!
-    @ident = +( map 0+ $_, Net::Address::Ethernet::get_address() )[ 3, 4, 5 ];
-    $ident = sprintf( '%02x%02x%02x', @ident );
-
-
-    sub _machine_ident
-    {
-        return wantarray ? @ident : $ident;
-    }
-}
-
-{
-    my $count_width    = 24;
-    my $count_mask     = 2**$count_width - 1;
-    my $count_format   = '%0' . int( $count_width / 4 ) . 'x';
-    my $count : shared = undef;
-
-
-    sub _reset_count
-    {
-        my ( $class, $value ) = @_;
-
-        lock $count;
-        $count = undef;
-
-        if ( defined $value ) {
-            $count = $count_mask & ( 0+ abs($value) );
-        }
-
-        unless ( defined $count ) {
-            my $random
-              = Crypt::Random::makerandom( Strength => 1, Uniform => 1, Size => $count_width );
-
-            # Can't share $random between threads, so coerce as string and
-            # assign to count
-            $count = "$random";
-        }
-        return $class;
-    }
-
-
-    sub _count
-    {
-        &_reset_count unless defined $count;
-        my $result = sprintf( $count_format, $count );
-        lock $count;
-        $count = $count_mask & ( 1 + $count );
-        return $result;
-    }
-}
-
-1;
-
 =pod
 
 =head1 REPOSITORY
